@@ -7,11 +7,12 @@ from ..models.encoders import EncoderFactory
 from ..models.q_functions import QFunctionFactory
 from ..augmentation import AugmentationPipeline
 from ..gpu import Device
-from ..argument_utility import ScalerArg
+from ..argument_utility import ScalerArg, ActionScalerArg
 from ..argument_utility import check_encoder, EncoderArg
 from ..argument_utility import check_use_gpu, UseGPUArg
 from ..argument_utility import check_q_func, QFuncArg
 from ..argument_utility import check_augmentation, AugmentationArg
+from ..constants import IMPL_NOT_INITIALIZED_ERROR
 
 
 class AWAC(AlgoBase):
@@ -69,6 +70,8 @@ class AWAC(AlgoBase):
             flag to use GPU, device ID or device.
         scaler (d3rlpy.preprocessing.Scaler or str): preprocessor.
             The available options are `['pixel', 'min_max', 'standard']`
+        action_scaler (d3rlpy.preprocessing.ActionScaler or str):
+            action preprocessor. The available options are ``['min_max']``.
         augmentation (d3rlpy.augmentation.AugmentationPipeline or list(str)):
             augmentation pipeline.
         generator (d3rlpy.algos.base.DataGenerator): dynamic dataset generator
@@ -120,6 +123,7 @@ class AWAC(AlgoBase):
         update_actor_interval: int = 1,
         use_gpu: UseGPUArg = False,
         scaler: ScalerArg = None,
+        action_scaler: ActionScalerArg = None,
         augmentation: AugmentationArg = None,
         generator: Optional[DataGenerator] = None,
         impl: Optional[AWACImpl] = None,
@@ -131,6 +135,7 @@ class AWAC(AlgoBase):
             n_steps=n_steps,
             gamma=gamma,
             scaler=scaler,
+            action_scaler=action_scaler,
             generator=generator,
         )
         self._actor_learning_rate = actor_learning_rate
@@ -175,6 +180,7 @@ class AWAC(AlgoBase):
             share_encoder=self._share_encoder,
             use_gpu=self._use_gpu,
             scaler=self._scaler,
+            action_scaler=self._action_scaler,
             augmentation=self._augmentation,
         )
         self._impl.build()
@@ -182,7 +188,7 @@ class AWAC(AlgoBase):
     def update(
         self, epoch: int, total_step: int, batch: TransitionMiniBatch
     ) -> List[Optional[float]]:
-        assert self._impl is not None
+        assert self._impl is not None, IMPL_NOT_INITIALIZED_ERROR
         critic_loss = self._impl.update_critic(
             batch.observations,
             batch.actions,
@@ -202,5 +208,5 @@ class AWAC(AlgoBase):
             actor_loss, mean_std = None, None
         return [critic_loss, actor_loss, mean_std]
 
-    def _get_loss_labels(self) -> List[str]:
+    def get_loss_labels(self) -> List[str]:
         return ["critic_loss", "actor_loss", "mean_std"]
