@@ -11,7 +11,8 @@ from ..argument_utility import check_encoder, EncoderArg
 from ..argument_utility import check_use_gpu, UseGPUArg
 from ..argument_utility import check_q_func, QFuncArg
 from ..argument_utility import check_augmentation, AugmentationArg
-from ..argument_utility import ScalerArg
+from ..argument_utility import ScalerArg, ActionScalerArg
+from ..constants import IMPL_NOT_INITIALIZED_ERROR
 
 
 class DDPG(AlgoBase):
@@ -70,6 +71,8 @@ class DDPG(AlgoBase):
             flag to use GPU, device ID or device.
         scaler (d3rlpy.preprocessing.Scaler or str): preprocessor.
             The available options are `['pixel', 'min_max', 'standard']`
+        action_scaler (d3rlpy.preprocessing.ActionScaler or str):
+            action preprocessor. The available options are ``['min_max']``.
         augmentation (d3rlpy.augmentation.AugmentationPipeline or list(str)):
             augmentation pipeline.
         generator (d3rlpy.algos.base.DataGenerator): dynamic dataset generator
@@ -113,6 +116,7 @@ class DDPG(AlgoBase):
         share_encoder: bool = False,
         use_gpu: UseGPUArg = False,
         scaler: ScalerArg = None,
+        action_scaler: ActionScalerArg = None,
         augmentation: AugmentationArg = None,
         generator: Optional[DataGenerator] = None,
         impl: Optional[DDPGImpl] = None,
@@ -124,6 +128,7 @@ class DDPG(AlgoBase):
             n_steps=n_steps,
             gamma=gamma,
             scaler=scaler,
+            action_scaler=action_scaler,
             generator=generator,
         )
         self._actor_learning_rate = actor_learning_rate
@@ -161,6 +166,7 @@ class DDPG(AlgoBase):
             share_encoder=self._share_encoder,
             use_gpu=self._use_gpu,
             scaler=self._scaler,
+            action_scaler=self._action_scaler,
             augmentation=self._augmentation,
         )
         self._impl.build()
@@ -168,7 +174,7 @@ class DDPG(AlgoBase):
     def update(
         self, epoch: int, total_step: int, batch: TransitionMiniBatch
     ) -> List[Optional[float]]:
-        assert self._impl is not None
+        assert self._impl is not None, IMPL_NOT_INITIALIZED_ERROR
         critic_loss = self._impl.update_critic(
             batch.observations,
             batch.actions,
@@ -182,5 +188,5 @@ class DDPG(AlgoBase):
         self._impl.update_actor_target()
         return [critic_loss, actor_loss]
 
-    def _get_loss_labels(self) -> List[str]:
+    def get_loss_labels(self) -> List[str]:
         return ["critic_loss", "actor_loss"]
