@@ -12,6 +12,7 @@ from ..argument_utility import check_encoder, EncoderArg
 from ..argument_utility import check_use_gpu, UseGPUArg
 from ..argument_utility import check_q_func, QFuncArg
 from ..argument_utility import check_augmentation, AugmentationArg
+from ..constants import IMPL_NOT_INITIALIZED_ERROR
 
 
 class DQN(AlgoBase):
@@ -97,6 +98,7 @@ class DQN(AlgoBase):
             n_steps=n_steps,
             gamma=gamma,
             scaler=scaler,
+            action_scaler=None,
             generator=generator,
         )
         self._learning_rate = learning_rate
@@ -134,7 +136,7 @@ class DQN(AlgoBase):
     def update(
         self, epoch: int, total_step: int, batch: TransitionMiniBatch
     ) -> List[Optional[float]]:
-        assert self._impl is not None
+        assert self._impl is not None, IMPL_NOT_INITIALIZED_ERROR
         loss = self._impl.update(
             batch.observations,
             batch.actions,
@@ -147,7 +149,7 @@ class DQN(AlgoBase):
             self._impl.update_target()
         return [loss]
 
-    def _get_loss_labels(self) -> List[str]:
+    def get_loss_labels(self) -> List[str]:
         return ["value_loss"]
 
 
